SystemOrganization addCategory: #'ScriptManager-Core'!

Model subclass: #ScriptManager
	instanceVariableNames: 'scriptListIndex bindingsList scriptList folderSelected folderList folderListIndex scripts fileName'
	classVariableNames: 'Scripts'
	poolDictionaries: ''
	category: 'ScriptManager-Core'!

!ScriptManager commentStamp: 'jp 5/25/2001 09:51' prior: 0!
The Script Manager offers a way to organize workspaces. It allows you to 
define "folders" in which you can store your scripts/workspaces. The folder 
menu provides options to import and export whole collections of scripts to
a file. The script menu offers options to "tear off" a script into a workspace, 
"bring in" workspaces, and to dump and load individual scripts to files.

Comments are appreciated.
- Joseph Pelrine
jpelrine@acm.org!

!ScriptManager class methodsFor: 'instance creation' stamp: 'tbn 5/15/2010 17:27'!
initialize
	Scripts := Dictionary new.
	self registerInWorldMenu! !

!ScriptManager class methodsFor: 'world menu' stamp: 'tbn 12/29/2010 10:08'!
menuCommandOn: aBuilder 
	<worldMenu> 
	(aBuilder item: #'Script Manager')
		parent: #Tools;
		icon: UITheme current smallLeftFlushIcon;
		action:[self open]! !

!ScriptManager class methodsFor: 'instance creation' stamp: 'jp 12/4/2000 09:25'!
open

	| newInst window |
	newInst := self new.
	window := (SystemWindow labelled: newInst label) model: newInst.
	newInst addMorphsTo: window.
	^window openInWorld! !

!ScriptManager class methodsFor: 'world menu' stamp: 'tbn 5/15/2010 17:27'!
registerInWorldMenu
	"This only applies to old Pharo 1.0 and Squeak"
	
	Smalltalk at: #TheWorldMenu ifPresent: [ :class |
		class class methodDict at: #registerOpenCommand: ifPresent: [ :method |
			(method sendsSelector: #deprecated:) 
				ifFalse: [ class registerOpenCommand: (Array with: self title with: (Array with: self with: #open)) ] ] ]! !

!ScriptManager class methodsFor: 'instance creation' stamp: 'jp 12/4/2000 09:15'!
scripts
	^Scripts! !

!ScriptManager class methodsFor: 'instance creation' stamp: 'jp 12/4/2000 09:15'!
scripts: aDictionary
	Scripts := aDictionary! !

!ScriptManager class methodsFor: 'user-interface' stamp: 'tbn 12/29/2010 10:05'!
taskbarIcon
	"Answer the icon for the receiver in a task bar."

	^UITheme current smallLeftFlushIcon! !

!ScriptManager class methodsFor: 'accessing' stamp: 'tbn 5/15/2010 17:29'!
title
	^'Script Manager'! !

!ScriptManager class methodsFor: 'clean up' stamp: 'tbn 5/15/2010 17:29'!
unload
	"Called when the class is being removed"

	self unregisterInWorldMenu! !

!ScriptManager class methodsFor: 'world menu' stamp: 'tbn 5/15/2010 17:28'!
unregisterInWorldMenu
	"This only applies to old Pharo 1.0 and Squeak"
	
	Smalltalk at: #TheWorldMenu ifPresent: [ :class |
		class class methodDict at: #unregisterOpenCommandWithReceiver: ifPresent: [ :method |
			(method sendsSelector: #deprecated:) 
				ifFalse: [ class unregisterOpenCommandWithReceiver: self ] ] ]! !

!ScriptManager methodsFor: 'drag&drop' stamp: 'tbn 2/2/2010 12:53'!
acceptDroppingMorph: transferMorph event: evt inMorph: dstListMorph 
	"Here we are fetching informations from the dropped transferMorph and 
	 performing the correct action for this drop."

	| srcListSel dstListSel |
	dstListSel := dstListMorph getListSelector.
	srcListSel := transferMorph source getListSelector.
	(dstListSel == #folderList and: [srcListSel == #scriptList]) ifTrue: [
		| newFolder oldFolder scriptName |
		newFolder := dstListMorph potentialDropItem contents.
		scriptName := transferMorph passenger contents.
		oldFolder := self selectedFolderName.
		oldFolder = newFolder ifFalse: [
			self 
				moveScriptNamed: scriptName
				from: oldFolder
				to: newFolder]]! !

!ScriptManager methodsFor: 'widgets' stamp: 'tbn 7/1/2011 08:49'!
addMorphsTo: aWindow
	"Add morphs to <aWindow>."
	 
	folderListIndex := 0.
	scriptListIndex := 0.
	aWindow
		addMorph: (self folderListWidget enableDragNDrop: true)
		frame: (0@0 extent: 0.4@0.4).
	aWindow 
		addMorph: (self scriptListWidget enableDragNDrop: true)
		frame: (0.4 @ 0.0 extent: 0.6 @ 0.4).

	aWindow
		addMorph: self buildTextMorph
		frame: ( 0@0.4 extent: 1@0.6)! !

!ScriptManager methodsFor: 'callbacks' stamp: 'kph 10/31/2006 00:48'!
bindingOf: aString 
	"store variable bindings per script."
	(self bindingsList
		at: self selectedScript
		ifAbsentPut: [Dictionary new])
		at: aString
		ifAbsentPut: [].
	^ (self bindingsList at: self selectedScript)
		associationAt: aString! !

!ScriptManager methodsFor: 'script list' stamp: 'tbn 1/26/2010 09:33'!
bindingsList
	^bindingsList ifNil: [ bindingsList := Dictionary new ]! !

!ScriptManager methodsFor: 'callbacks' stamp: 'tbn 2/2/2010 11:39'!
bringInScripts
	| wsDictionary selected |
	wsDictionary := self workspaceDictionary.
	wsDictionary isEmpty
		ifTrue: [ UIManager default inform: 'No workspaces currently open.'.
			^ self].
	(selected := self chooseWorkspace: wsDictionary) isNil
		ifTrue: [^ self].
	self installWorkspaceScripts: selected! !

!ScriptManager methodsFor: 'widgets' stamp: 'AlainPlantec 8/26/2011 17:46'!
buildTextMorph 

	^( PluggableTextMorph
				on: self
				text: #contents
				accept: #contents:notifying:
				readSelection: #contentsSelection
				menu: #codePaneMenu:shifted:)
			font: StandardFonts codeFont;
			yourself! !

!ScriptManager methodsFor: 'callbacks' stamp: 'jp 12/5/2000 11:25'!
changeFolder
	| newFolder oldFolder scriptName |
	self isScriptSelected ifFalse: [^nil].
	scriptName := self selectedScriptName.
	oldFolder := self selectedFolderName.
	((newFolder := self chooseFolderToMoveTo) isNil 
		or: [oldFolder = newFolder]) ifTrue: [^nil].
	self 
		moveScriptNamed: scriptName
		from: oldFolder
		to: newFolder! !

!ScriptManager methodsFor: 'menus' stamp: 'jp 12/4/2000 12:25'!
changeFolderString
	^'change folder'! !

!ScriptManager methodsFor: 'callbacks' stamp: 'tbn 3/26/2007 14:39'!
chooseFolderToMoveTo
	| folders |
	folders := self folderList copyWithout: self selectedFolderName.
	^ UIManager default
		chooseFrom: folders
		values: folders
		title: 'Please select the new folder'! !

!ScriptManager methodsFor: 'callbacks' stamp: 'dc 3/26/2007 10:09'!
chooseWorkspace: aDictionary

	| list |
	list := aDictionary associations asSortedCollection: [ :a :b | a key < b key].
	^ UIManager default
		chooseFrom: (list collect: [ :each | each key]) 
		values: list
		title: 'Please select the workspaces'! !

!ScriptManager methodsFor: 'callbacks' stamp: 'jp 12/5/2000 07:23'!
clearUserEditFlag
	"Clear the hasUnacceptedEdits flag in all my dependent views."
	"don't remove this method.  Just don't."

	self changed: #clearUserEdits! !

!ScriptManager methodsFor: 'editor' stamp: 'tbn 9/18/2006 18:25'!
codePaneMenu: aMenu shifted: shifted
	"Note that unless we override perform:orSendTo:, PluggableTextController will respond to all menu items in a text pane"
	| donorMenu |
	donorMenu := shifted
		ifTrue:
			[ParagraphEditor shiftedYellowButtonMenu]
		ifFalse:
			[ParagraphEditor yellowButtonMenu].
	^ aMenu addAllFrom: donorMenu! !

!ScriptManager methodsFor: 'editor' stamp: 'jp 12/4/2000 09:44'!
contents
	| script |
	^(script := self selectedScript) = nil 
		ifTrue: ['']
		ifFalse: 	[script]! !

!ScriptManager methodsFor: 'editor' stamp: 'jp 12/4/2000 14:41'!
contents: aString notifying: aController 
	self selectedFolder
		at: self selectedScriptName
		put: aString string.
	^true! !

!ScriptManager methodsFor: 'editor' stamp: 'jp 12/4/2000 09:47'!
contentsSelection
	"Return the interval of text in the code pane to select when I set the pane's contents"

	(self folderListIndex = 0 and: [scriptListIndex = 0]) 
		ifTrue: [^ 1 to: 500]	"entire empty method template"
		ifFalse: [^ 1 to: 0]  "null selection"! !

!ScriptManager methodsFor: 'callbacks' stamp: 'jp 12/4/2000 14:09'!
createFolderNamed: newFolderName 
	self scripts at: newFolderName put: Dictionary new.
	self
		changed: #folderList;
		changed: #scriptList! !

!ScriptManager methodsFor: 'callbacks' stamp: 'jp 12/4/2000 10:43'!
deleteFolder
	self isFolderSelected ifFalse: [^nil].
	self scripts 
		removeKey: self selectedFolderName
		ifAbsent: [].
	self folderListIndex: 0
! !

!ScriptManager methodsFor: 'callbacks' stamp: 'jp 12/4/2000 12:48'!
deleteScript
	self isScriptSelected ifFalse: [^nil].
	self selectedFolder 
		removeKey: self selectedScriptName
		ifAbsent: [].
	self 
		changed: #scriptList;
		scriptListIndex: 0
! !

!ScriptManager methodsFor: 'menus' stamp: 'jp 12/4/2000 12:22'!
deleteString
	^'delete'! !

!ScriptManager methodsFor: 'drag&drop' stamp: 'jp 12/5/2000 11:21'!
dragTransferTypeForMorph: dragSource 
	^(dragSource isKindOf: PluggableListMorph)
		ifTrue: [dragSource getListSelector]! !

!ScriptManager methodsFor: 'callbacks' stamp: 'tbn 2/2/2010 11:37'!
dumpScriptToFile
	| aFileName fileStream |
	aFileName := UIManager default request: 'Name of file to dump script to: '.
	aFileName isEmptyOrNil ifTrue: [^ self].
	fileStream := FileStream fileNamed: aFileName.
	fileStream nextPutAll: self contents; close! !

!ScriptManager methodsFor: 'menus' stamp: 'jp 5/25/2001 09:43'!
dumpToFileString
	^'dump to file...'! !

!ScriptManager methodsFor: 'callbacks' stamp: 'tbn 2/2/2010 12:24'!
exportScripts

	| rr exportFileName |
	exportFileName := UIManager default 
		request: 'File name? (".obj" will be added to end)' 
		initialAnswer: self storageFileName.
	exportFileName isEmptyOrNil ifTrue: [^ Beeper beep].
	(exportFileName asLowercase endsWith: '.obj') ifFalse: [
		exportFileName := exportFileName,'.obj'].
	
	((FileDirectory default fileExists: exportFileName) 
		and: [(UIManager default confirm: 'Overwrite file ', exportFileName) = false]) ifTrue: [^self].
				
	Cursor wait showWhile: [
		rr := ReferenceStream fileNamed: exportFileName.
		rr nextPut:  self scripts.
		rr close].
	self fileName: exportFileName


! !

!ScriptManager methodsFor: 'callbacks' stamp: 'tbn 1/26/2010 09:33'!
fileName
	fileName isNil ifTrue: [fileName := self storageFileName].
	^fileName! !

!ScriptManager methodsFor: 'callbacks' stamp: 'tbn 1/26/2010 09:32'!
fileName: aString
	fileName  := aString.
	(fileName asLowercase endsWith: '.obj') ifTrue: [
		fileName := fileName copyFrom: 1 to: fileName size - 4].
	self topView setLabel: self label, ' - ', self fileName! !

!ScriptManager methodsFor: 'callbacks' stamp: 'jp 12/4/2000 13:43'!
firstLineFor: aString
	| lines stream |
	lines := OrderedCollection new.
	stream := aString readStream.
	[stream atEnd] whileFalse: [
		lines addLast: stream nextLine withBlanksTrimmed].
	^lines
		detect: [ :each | each isEmpty not 
			and: [((each size = 1) and: [each first = $"]) not]]
		ifNone: [ nil ]! !

!ScriptManager methodsFor: 'folder list' stamp: 'jp 12/4/2000 09:16'!
folderList
	^self scripts keys asSortedCollection! !

!ScriptManager methodsFor: 'folder list' stamp: 'jp 5/25/2001 09:45'!
folderListIndex
	folderListIndex == nil
		ifTrue: [^0].
	^folderListIndex! !

!ScriptManager methodsFor: 'folder list' stamp: 'tbn 1/26/2010 09:32'!
folderListIndex: anInteger 
	"Set the selected folder index to be anInteger. Update all other 
	selections to be deselected."
	folderListIndex := anInteger.
	scriptListIndex := 0.
	self 
		changed: #folderList;	"update my selection"
		changed: #scriptList;
		changed: #contents.! !

!ScriptManager methodsFor: 'menus' stamp: 'jp 12/4/2000 12:22'!
folderListMenu: aMenu
	^ aMenu
		add: 'new folder ...' action: #newFolder;
		addUpdating: #renameString enablement: #isFolderSelected action: #renameFolder;
		addUpdating: #deleteString enablement: #isFolderSelected action: #deleteFolder;
		addLine;
		add: 'import' action: #importScripts;
		add: 'export' action: #exportScripts;
	yourself
! !

!ScriptManager methodsFor: 'widgets' stamp: 'jp 12/4/2000 08:55'!
folderListWidget
	^PluggableListMorph 
		on: self
		list: #folderList
		selected: #folderListIndex
		changeSelected: #folderListIndex:
		menu: #folderListMenu:
		keystroke: nil! !

!ScriptManager methodsFor: 'callbacks' stamp: 'kph 10/31/2006 00:45'!
hasBindingOf: aString 
 
	(self bindingsList
		at: self selectedScript
		ifAbsent: [ ^false ])
		at: aString
		ifAbsent: [ ^false ].
	^ true! !

!ScriptManager methodsFor: 'shout support' stamp: 'tbn 11/17/2005 09:05'!
hasBindingThatBeginsWith: aString
	"we dont support bindings here"

	^false
! !

!ScriptManager methodsFor: 'callbacks' stamp: 'tbn 2/2/2010 12:08'!
importScripts

	| rr importFileName importedScripts |
	importFileName := UIManager default 
		request: 'File name? (".obj" will be added to end)' 
		initialAnswer: self fileName.
	importFileName isEmptyOrNil ifTrue: [^ Beeper beep ].
	(importFileName asLowercase endsWith: '.obj') ifFalse: [
		importFileName := importFileName,'.obj'].
	
	(FileDirectory default fileExists: importFileName) 
		ifFalse: [^UIManager default inform: 'File ', importFileName, ' does not exist!!' ].	
			
	Cursor wait showWhile: [
		rr := ReferenceStream fileNamed: importFileName.
		importedScripts := rr next.
		rr close].
	importedScripts ~~ nil ifTrue: [self scripts: importedScripts].
	self
		changed: #folderList;
		folderListIndex: 0;
		fileName: importFileName
! !

!ScriptManager methodsFor: 'callbacks' stamp: 'dc 3/26/2007 10:11'!
installWorkspaceScripts: selected
	(self folderList includes: 'workspaces') ifFalse: [
		self createFolderNamed: 'workspaces'].
	(self scripts at: 'workspaces')
		at: selected key put: selected value.
	self selectFolderNamed: 'workspaces'.
! !

!ScriptManager methodsFor: 'folder list' stamp: 'jp 12/4/2000 10:45'!
isFolderSelected
	^folderListIndex ~= 0! !

!ScriptManager methodsFor: 'script list' stamp: 'jp 12/4/2000 10:45'!
isScriptSelected
	^scriptListIndex ~= 0! !

!ScriptManager methodsFor: 'callbacks' stamp: 'jp 12/4/2000 09:26'!
label
	^'Script Manager'! !

!ScriptManager methodsFor: 'callbacks' stamp: 'tbn 2/2/2010 11:48'!
loadScriptFromFile
	| aFileName fileStream assoc string |
	aFileName := UIManager default request: 'Name of file to be loaded: '.
	aFileName isEmptyOrNil ifTrue: [^ self].
	(FileDirectory default fileExists: aFileName) ifFalse:
		[^ self inform: 'Sorry -- cannot find that file'].
	fileStream := FileStream readOnlyFileNamed: aFileName.
	string := fileStream contents.
	fileStream close.
	assoc := Association key: aFileName value: string.
	self installWorkspaceScripts: (Array with: assoc)! !

!ScriptManager methodsFor: 'callbacks' stamp: 'tbn 3/26/2007 14:43'!
localWorkspaces
	| world systemWindows |
	world := self dependents first world.
	systemWindows := world submorphs
				select: [:each | each model isKindOf: Workspace].
	^ systemWindows
		collect: [:each | each model dependents
				detect: [:e | e isKindOf: PluggableTextMorph]]! !

!ScriptManager methodsFor: 'callbacks' stamp: 'tbn 2/2/2010 12:52'!
moveScriptNamed: scriptName from: oldFolder to: newFolder
	| myScript |
	myScript := self selectedFolder at: scriptName.
	(self scripts at: newFolder) at: scriptName put: myScript.
	(self scripts at: oldFolder) removeKey: scriptName.
	self selectFolderNamed: oldFolder! !

!ScriptManager methodsFor: 'callbacks' stamp: 'tbn 2/2/2010 11:42'!
newFolder
	| newFolderName |
	(newFolderName := self promptForNewName) isEmptyOrNil ifTrue: [^nil].
	(self folderList includes: newFolderName) ifTrue: [
		^UIManager default inform: 'A folder named ' , newFolderName , ' already exists'].
	self createFolderNamed: newFolderName! !

!ScriptManager methodsFor: 'callbacks' stamp: 'tbn 2/2/2010 11:42'!
newScript
	| scriptName index |
	self isFolderSelected ifFalse: [^nil].
	(scriptName := self promptForNewName) isEmptyOrNil ifTrue: [^nil].
	(self scriptList includes: scriptName) ifTrue: [
		^UIManager default inform: 'A script named ', scriptName, ' already exists'].
	self selectedFolder at: scriptName put: ''.
	self changed: #scriptList.
	index := self scriptList indexOf: scriptName.
	self 
		changed: #scriptList;
		scriptListIndex: index
! !

!ScriptManager methodsFor: 'menus' stamp: 'jp 12/4/2000 12:27'!
newScriptString
	^'new script ...'! !

!ScriptManager methodsFor: 'callbacks' stamp: 'jp 5/25/2001 09:42'!
okToChange
	self canDiscardEdits ifTrue: [^ true].
	self changed: #wantToChange.  "Solicit cancel from view"
	^self canDiscardEdits! !

!ScriptManager methodsFor: 'editor' stamp: 'tbn 2/2/2010 09:28'!
perform: selector orSendTo: otherTarget
	"Selector was just chosen from a menu by a user.  If can respond, then
perform it on myself. If not, send it to otherTarget, presumably the
editPane from which the menu was invoked."

	(self respondsTo: selector)
		ifTrue: [^ self perform: selector]
		ifFalse: [^ otherTarget perform: selector]! !

!ScriptManager methodsFor: 'callbacks' stamp: 'tbn 2/2/2010 11:14'!
promptForNewName
	^UIManager default request: 'New name?'
! !

!ScriptManager methodsFor: 'callbacks' stamp: 'tbn 2/2/2010 11:14'!
promptForNewName: aString
	^UIManager default request: 'New name?' initialAnswer: aString.
	
 ! !

!ScriptManager methodsFor: 'callbacks' stamp: 'tbn 2/2/2010 11:43'!
renameFolder
	| newName oldName myScripts |
	self isFolderSelected
		ifFalse: [^ nil].
	oldName := self selectedFolderName.
	((newName := self promptForNewName: oldName) isEmptyOrNil
			or: [oldName = newName])
		ifTrue: [^ nil].
	(self folderList includes: newName)
		ifTrue: [^ UIManager default inform: 'a folder named ' , newName , ' already exists'].
	myScripts := self scripts at: oldName.
	self scripts at: newName put: myScripts;
		 at: oldName put: nil.
	self scripts removeKey: oldName.
	self selectFolderNamed: newName! !

!ScriptManager methodsFor: 'callbacks' stamp: 'tbn 2/2/2010 11:43'!
renameScript
	| newName oldName index myScript |
	self isScriptSelected
		ifFalse: [^ nil].
	oldName := self selectedScriptName.
	((newName := self promptForNewName: oldName) isEmpty
			or: [oldName = newName])
		ifTrue: [^ nil].
	(self scriptList includes: newName)
		ifTrue: [^ UIManager default inform: 'a script named ' , newName , ' already exists'].
	myScript := self selectedFolder at: oldName.
	self selectedFolder at: newName put: myScript;
		 at: oldName put: nil.
	self selectedFolder removeKey: oldName.
	index := self folderList indexOf: newName.
	self changed: #scriptList;
		 scriptListIndex: index! !

!ScriptManager methodsFor: 'menus' stamp: 'jp 12/4/2000 12:21'!
renameString
	^'rename ...'! !

!ScriptManager methodsFor: 'script list' stamp: 'jp 12/4/2000 10:42'!
scriptList
	"Returns the list of scripts in the folder"

	^self selectedFolder isNil 
		ifTrue: [Array new]
		ifFalse: [self selectedFolder keys asSortedCollection]
! !

!ScriptManager methodsFor: 'script list' stamp: 'jp 5/25/2001 09:31'!
scriptListIndex
	scriptListIndex == nil
		ifTrue: [^0].
	^scriptListIndex
! !

!ScriptManager methodsFor: 'script list' stamp: 'jp 12/4/2000 09:55'!
scriptListIndex: anInteger
	scriptListIndex := anInteger.
	self 
		changed: #scriptListIndex;
		changed: #contents.

! !

!ScriptManager methodsFor: 'menus' stamp: 'jp 5/25/2001 09:44'!
scriptListMenu: aMenu
	^ aMenu
		addUpdating: #newScriptString enablement: #isFolderSelected action: #newScript;
		addUpdating: #renameString enablement: #isScriptSelected action: #renameScript;
		addUpdating: #deleteString enablement: #isScriptSelected action: #deleteScript;
		addUpdating: #changeFolderString enablement: #isScriptSelected action: #changeFolder;
		addLine;
		addUpdating: #tearOffString enablement: #isScriptSelected action: #tearOffScript;
		add: 'bring in' action: #bringInScripts;
		addLine;
		addUpdating: #dumpToFileString enablement: #isScriptSelected action: #dumpScriptToFile;
		add: 'load from file...' action: #loadScriptFromFile;
	yourself
! !

!ScriptManager methodsFor: 'widgets' stamp: 'jp 12/4/2000 09:12'!
scriptListWidget
	^PluggableListMorph 
		on: self
		list: #scriptList
		selected: #scriptListIndex
		changeSelected: #scriptListIndex:
		menu: #scriptListMenu:
		keystroke: nil! !

!ScriptManager methodsFor: 'folder list' stamp: 'tbn 1/26/2010 09:30'!
scripts
	scripts isNil ifTrue: [scripts := self class scripts].
	^scripts! !

!ScriptManager methodsFor: 'folder list' stamp: 'tbn 1/26/2010 09:30'!
scripts: aDictionary
	scripts := aDictionary! !

!ScriptManager methodsFor: 'callbacks' stamp: 'jp 12/4/2000 14:11'!
selectFolderNamed: newName 
	| index |
	index := self folderList indexOf: newName.
	self
		changed: #folderList;
		folderListIndex: index! !

!ScriptManager methodsFor: 'folder list' stamp: 'jp 12/4/2000 10:04'!
selectedFolder
	self selectedFolderName isNil ifTrue: [^nil].
	^self scripts at: self selectedFolderName ifAbsentPut: [Dictionary new].
! !

!ScriptManager methodsFor: 'folder list' stamp: 'jp 12/4/2000 10:44'!
selectedFolderName
	self isFolderSelected ifFalse: [^nil].
	^self folderList at: folderListIndex! !

!ScriptManager methodsFor: 'script list' stamp: 'jp 12/4/2000 10:47'!
selectedScript
	(self selectedFolder isNil or: [self selectedScriptName isNil])
	  	ifTrue: [^nil].
	^self selectedFolder at: self selectedScriptName! !

!ScriptManager methodsFor: 'script list' stamp: 'jp 12/4/2000 10:45'!
selectedScriptName
	^self isScriptSelected 
		ifTrue: [self scriptList at: scriptListIndex]
		ifFalse: []! !

!ScriptManager methodsFor: 'callbacks' stamp: 'jp 12/4/2000 12:06'!
storageFileName
	^'scripts'
! !

!ScriptManager methodsFor: 'callbacks' stamp: 'tbn 2/2/2010 11:23'!
tearOffScript
	| wsClass ws |
	wsClass := (Smalltalk at: #SHWorkspace ifAbsent: [Workspace]).
	ws := wsClass new contents: self contents.
	ws openLabel: 'Workspace' ! !

!ScriptManager methodsFor: 'menus' stamp: 'jp 12/4/2000 12:25'!
tearOffString
	^'tear off'! !

!ScriptManager methodsFor: 'drag&drop' stamp: 'tbn 1/26/2010 09:30'!
wantsDroppedMorph: transferMorph event: anEvent inMorph: destinationLM 

	| srcType dstType |
	(destinationLM isKindOf: PluggableTextMorph) ifTrue: [ ^ false ].
	srcType := transferMorph dragTransferType.
	dstType := destinationLM getListSelector.
	dstType == #folderList ifTrue: [^true].
"self hack."	"to-do:  this needs to check that source browser and dest browser are the same"
	(srcType == #scriptList) ifTrue: [^true].
	^false! !

!ScriptManager methodsFor: 'callbacks' stamp: 'dc 3/26/2007 10:14'!
workspaceDictionary
	^ self localWorkspaces
		inject: Dictionary new
		into: [:dictionary :workspace | 
		| key string line |
		line := self firstLineFor: (string := workspace text string).
		line isNil 
			ifFalse: [dictionary at: (line copyFrom: 1 to: (80 min: line size)) put: string].
		dictionary].! !
ScriptManager initialize!
